.. BicycleParameters documentation master file, created by
   sphinx-quickstart on Wed Jun 29 15:30:42 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

==================================
BicycleParameters's documentation!
==================================

The **bicycleparameters** package is a python program designed to produce and
manipulate the basic parameters needed for basic bicycle dynamic models.

Table of Contents
=================

.. toctree::
   :maxdepth: 2

   description.rst
   installation.rst
   examples.rst
   data.rst
   app.rst
   bicycleparameters.rst

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
